@@ -28,7 +28,7 @@ from werkzeug.exceptions import RequestEntityTooLarge, UnsupportedMediaType
 
 from . import utils
 
-__version__ = '0.8.1'
+__version__ = '0.8.2'
 
 
 IMAGES = ('.jpg', '.jpeg', '.png', '.gif', '.bmp')
@@ -150,7 +150,7 @@ class FileStorage(object):
     def __repr__(self):
         return '<%s "%s" secret=%s>' % (self.__class__.__name__,
             self.upload_to, self.secret)
-    
+
     def save(self, filesto, upload_to=None, secret=None, prefix=None,
             allowed=None, denied=None, max_size=None):
         """
@@ -266,6 +266,8 @@ class FileStorage(object):
         }
         return File(data, self.base_path, self.base_url)
     
+    __call__ = save
+
     def validate(self, filesto, allowed=None, denied=None, max_size=None):
         max_size = max_size or self.max_size
         content_length = filesto.content_length
@@ -328,8 +330,7 @@ class File(object):
         return bool(self.path)
     
     def __repr__(self):
-        return '<%s %s "%s">' % (self.__class__.__name__,
-            self.type, self.name)
+        return self.to_json()
     
     def remove(self):
         try:
@@ -345,12 +346,14 @@ class File(object):
             'relpath': self.relpath,
             'size': self.size,
             'type': self.type,
+            'url': self.url,
             'remote_url': self.remote_url,
         }
         if self.width:
             data['width'] = self.width
         if self.height:
             data['height'] = self.height
+        print 'DATA', data
         return data
     
     def to_json(self):
